@@ -295,7 +295,7 @@ class GoodData:
             afm = {"execution": afm}
         elif not "execution" in afm:
             raise ValueError("afm should be a dictionary either containing key 'afm' or 'execution' in its root")
-        response = self.session.post(url, json=afm)
+        response = self.session.post(url, json=afm, headers=self.headers)
         return response.json()["executionResponse"]["links"]["executionResult"]
 
     def export_afm_result(self, execution_result: str, fname: str, title: str = "csv export"):
@@ -314,7 +314,7 @@ class GoodData:
                 "exportConfig": {"format": "csv", "title": title},
             }
         }
-        response = self.session.post(url, json=data)
+        response = self.session.post(url, json=data, headers=self.headers)
         while response.status_code != 200:
             sleep(1)
             try:
@@ -325,7 +325,7 @@ class GoodData:
                 self.logger.error("status_code: %d", response.status_code)
                 raise error
             url = _url(self.domain, target_link)
-            response = self.session.get(url)
+            response = self.session.get(url, headers=self.headers)
         with open(fname, "w", encoding="utf-8") as fid:
             fid.write(response.text)
 
